#!/bin/bash

# functions
log() {
#  if [ -z "${LOG_FILEPATH}" ]; then
#    echo "${SCRIPT_NAME}($$) "`date +"%y%m%d-%H%M%S:"`" Instance:${HANADB_INST} Schema:\"${SCHEMA_NAME}\" $*";
#  else
if [ ! -z ${NEW_SCHEMA_NAME} ]; then
	echo "${SCRIPT_NAME}($$) "`date +"%y%m%d-%H%M%S:"`" Instance:${HANADB_INST} Schema:\"${NEW_SCHEMA_NAME}\" $*" >>$LOG_FILEPATH;
else
    echo "${SCRIPT_NAME}($$) "`date +"%y%m%d-%H%M%S:"`" Instance:${HANADB_INST} Schema:\"${SCHEMA_NAME}\" $*" >>$LOG_FILEPATH;
fi
#  fi
}

err() { log "ERROR: $*"; }

print_help() {
  echo -e "${SCRIPT_NAME} version 1.0, helper tool for wrapping execution of HANA DB backup utility when executing from cron\n"
  echo -e "usage:"
  echo -e "  ${SCRIPT_NAME} -t <backup_tool> -a <backup_action> -v <backup_Tool_Library_Path> -n <hana_db_server:hana_db_port> -u <hana_db_user> -p <hana_db_pass> -s <schema> -b <backup_path> [-o] [-l <log_file>] [-w <working_path>]\n"
  echo -e "  -t <backup_tool>"
  echo -e "  -a <backup | restore | list | backup_server | delete_older_backups | check_open_sessions | copy_export>"
  echo -e "  -v <backup_Tool_Library_Path>"
  echo -e "  -n <hana_db_server:hana_db_port>"
  echo -e "  -u <hana_db_user>"
  echo -e "  -p <hana_db_pass>"
  echo -e "  -s <schema>"
  echo -e "  -r <new_schem_name>"
  echo -e "  -b <backup_path>"
  echo -e "  -c compress"
  echo -e "  -m <limit size in MB>"
  echo -e "  -o                 overwrite - Import operation: overwrite target schema; Export operation: overwrite oldest export when size limit is reached"
  echo -e "  -l <log_file>      log file for all output from this script and its child procesess [/var/log/sap/backup/backup.log]"
  echo -e "  -w <working_path>  a folder where the HANA DB will export the schema"
  echo -e "  -d <timestamp>     timestamp for import operation"
  echo -e "  -g <GUID>			GUID of the operation used for identification purposes"
  echo -e "  -k 				kill another open sessions to schema for export operation"
  echo -e "  -x <Yes | No>      delete older backups after successful backup server operation"
  echo -e "  -e <server share>  share for copy_export operation"
  echo -e "  -f <subfolder>     subfolder of share for copy_export operation - may be empty"
  echo -e "  -q <user>          user with access to share for copy_export operation"
  echo -e "  -i <password>      password of user for copy_export operation"
  echo -e "  -j <path>          path to zip file for copy_export operation"
  echo -e ""
}

getInstanceNo() {
  local arr=(${1//:/ })
  local instanceNo=${arr[1]:1:2}
  [ -z "${instanceNo}" ] && instanceNo="00"
  echo ${instanceNo}
}

getInstancePortNo() {
  local arr=(${1//:/ })
  local instancePortNo=${arr[1]}
  [ -z "${instancePortNo}" ] && instancePortNo="30015"
  echo ${instancePortNo}
}

getInstanceUnique() {
  local uniq=${1//:/_}
  [ -z "${uniq}" ] && uniq="localhost_30015"
  echo ${uniq}
}

# internal vars
NOW=`date +"%y%m%d_%H%M%S"`
SCRIPT_NAME=`basename $0`

# input parameters
LOG_FILEPATH=/var/log/sap/backup/backup.log
WORKING_PATH=/tmp
KILL_OPEN_SESSIONS=""

readopt='getopts "$opts" opt;rc=$?;[ $rc == 0 ]||{ shift $[OPTIND-1];false; }'

opts=hckv:t:a:on:u:s:r:p:b:l:w:m:d:g:x:e:f:q:i:j:

while eval $readopt
do
case $opt in
    h)  print_help
        exit
        ;;
    c)  COMPRESS="-compress"
        ;; 
    k)  KILL_OPEN_SESSIONS="-killopensessions"
		;;       
    t)  BACKUP_TOOL=$OPTARG
        ;;
    a)  BACKUP_ACTION=$OPTARG
        ;;
    v)  BACKUP_TOOL_LIBRARY_PATH=$OPTARG
        ;;
    n)  HANADB_INST=$OPTARG
        ;;
    u)  HANADB_USER=$OPTARG
        ;;
    p)  HANADB_PASS=$OPTARG
        ;;
    s)  SCHEMA_NAME=$OPTARG
        ;;
	r)	NEW_SCHEMA_NAME=$OPTARG
		;;
    o)  OVERWRITE="-overwrite"
        ;;
    b)  BACKUP_PATH=$OPTARG
        ;;
    l)  LOG_FILEPATH=$OPTARG
        ;;
    w)  WORKING_PATH=$OPTARG
        ;;
    d)  TIMESTAMP=$OPTARG
	    ;;
    m)	LIMIT=$OPTARG
	    ;;
    g)  GUID=$OPTARG
        ;;
    x)  DELETE_OLDER_BACKUPS=$OPTARG
        ;;
    e)  COPYSERVER=$OPTARG
        ;;
    f)  COPYSUBFOLDER=$OPTARG
        ;;
    q)  COPYUSER=$OPTARG
        ;;
    i)  COPYPASSWORD=$OPTARG
        ;;
    j)  COPYBACKUPPATH=$OPTARG
        ;;
esac
done

SCHEMA_NAME=${SCHEMA_NAME//\"}

error=0
# check/prepare log folder
if [ -n "${LOG_FILEPATH}" ]; then
  LOG_PATH=`dirname ${LOG_FILEPATH}`
  [ ! -e ${LOG_PATH} ] && mkdir -p ${LOG_PATH} >/dev/null 2>&1
  [ ! -e ${LOG_PATH} ] && error=7 && LOG_FILEPATH="" && err "Can not access log file path ${LOG_PATH}"
  [ "${error}" -ne "0" ] && exit;# ${error}
else
  LOG_FILEPATH=/dev/stdout
fi


# input validation
[ -z "${HANADB_INST}" ] && error=1 && err "Missing Hana DB Server"
if [ -z "${HANADB_USER}" ] && [[ ${BACKUP_ACTION} != "list" && ${BACKUP_ACTION} != "copy_export" ]]; then 
	error=2 
	err "Missing Hana DB user"
fi
if [ -z "${HANADB_PASS}" ] && [[ ${BACKUP_ACTION} != "list" && ${BACKUP_ACTION} != "copy_export" ]]; then
	error=3
	err "Missing Hana DB user password"
fi
[[ -z "${SCHEMA_NAME}" && ${BACKUP_ACTION} != "backup_server" && ${BACKUP_ACTION} != "delete_older_backups" && ${BACKUP_ACTION} != "list" ]] && error=4 && err "Missing Hana DB schema name"
[[ -z "${BACKUP_PATH}" && ${BACKUP_ACTION} != "copy_export" ]] && error=5 && err "Missing Hana DB backup path"
[ -z "${BACKUP_TOOL}" ] && error=6 && err "Missing backup tool"
[ -z "${BACKUP_ACTION}" ] && error=6 && err "Missing backup action"
[ -z "${BACKUP_TOOL_LIBRARY_PATH}" ] && error=7 && err "Missing backup tool library path"
[[ -z "${GUID}" && ${BACKUP_ACTION} = "copy_export" ]] && error=8 && err "Missing GUID"
[[ -z "${COPYSERVER}" && ${BACKUP_ACTION} = "copy_export" ]] && error=14 && err "Missing server with share"
[[ -z "${COPYUSER}" && ${BACKUP_ACTION} = "copy_export" ]] && error=15 && err "Missing user for accessing the share"
[[ -z "${COPYPASSWORD}" && ${BACKUP_ACTION} = "copy_export" ]] && error=16 && err "Missing password for the user for accessing the share"
[[ -z "${COPYBACKUPPATH}" && ${BACKUP_ACTION} = "copy_export" ]] && error=17 && err "Missing path to file for copying"
[ "${error}" -ne "0" ] && exit;# ${error}

# 
instanceUniq=$(getInstanceUnique ${HANADB_INST})
if [ ! -z ${NEW_SCHEMA_NAME} ]; then
	PID_FILE_PATH=${LOG_PATH}/${NEW_SCHEMA_NAME}.pid
else
	PID_FILE_PATH=${LOG_PATH}/${SCHEMA_NAME}.pid
fi

# check if already running the same schema backup
echo $$ >>"${PID_FILE_PATH}"
read OTHER_PID <"${PID_FILE_PATH}"
[ "${OTHER_PID}" -ne "$$" -a ! -d /proc/${OTHER_PID} ] && log "Found stale pid file ${PID_FILE_PATH} with pid(${OTHER_PID})"
[ "${OTHER_PID}" -ne "$$" -a -d /proc/${OTHER_PID} ] && error=12 && log "Found pid file ${PID_FILE_PATH} with running pid(${OTHER_PID})"
[ "${error}" -ne "0" ] && err "Other operation on the same schema in progress ${HANADB_INST} ${SCHEMA_NAME}" && exit;# ${error}
echo $$ >"${PID_FILE_PATH}"
read OTHER_PID <"${PID_FILE_PATH}"
[ "${OTHER_PID}" -ne "$$" ] && error=13 && log "Found pid file ${PID_FILE_PATH} with other starting pid(${OTHER_PID})"
[ "${error}" -ne "0" ] && err "Other operation on the same schema in progress ${HANADB_INST} ${SCHEMA_NAME}" && exit;# ${error}
log "Pid file ${PID_FILE_PATH}"

if [[ ${BACKUP_ACTION} = "backup" || ${BACKUP_ACTION} = "backup_server" ]]; then
	log "Begin: Timestamp:${NOW} User:${HANADB_USER} Password:**** BackupPath:${BACKUP_PATH} LogFile:${LOG_FILEPATH} WorkingPath:${WORKING_PATH}"
	if [ ! -z ${GUID} ]; then
		log "GUID:${GUID}"
	else
		log "GUID:"
	fi
fi
if [ ${BACKUP_ACTION} = "restore" ]; then
	log "Importing: Timestamp:${NOW} User:${HANADB_USER} Password:**** BackupPath:${BACKUP_PATH} LogFile:${LOG_FILEPATH} WorkingPath:${WORKING_PATH}"
	if [ ! -z ${GUID} ]; then
		log "GUID:${GUID}"
	else
		log "GUID:"
	fi
fi

# execution part
if [ ${BACKUP_ACTION} = "restore" ]; then
	if [ ! -z ${TIMESTAMP} ]; then
		if [ ! -z ${NEW_SCHEMA_NAME} ]; then
			log ${BACKUP_TOOL} ${BACKUP_ACTION} -dbserver ${HANADB_INST} -database ${SCHEMA_NAME} -newdbname ${NEW_SCHEMA_NAME} -location ${BACKUP_PATH} -timestamp ${TIMESTAMP} -dbuser ${HANADB_USER} -dbpassword "****" ${OVERWRITE} -t ${WORKING_PATH} >>$LOG_FILEPATH 2>&1
			sudo LC_ALL=en_US.UTF-8 LD_LIBRARY_PATH=$LD_LIBRARY_PATH:${BACKUP_TOOL_LIBRARY_PATH} ${BACKUP_TOOL} ${BACKUP_ACTION} -dbserver ${HANADB_INST} -database ${SCHEMA_NAME} -newdbname ${NEW_SCHEMA_NAME} -location ${BACKUP_PATH} -timestamp ${TIMESTAMP} -dbuser ${HANADB_USER} -dbpassword ${HANADB_PASS} ${OVERWRITE} -t ${WORKING_PATH} >>$LOG_FILEPATH 2>&1
		else
			log ${BACKUP_TOOL} ${BACKUP_ACTION} -dbserver ${HANADB_INST} -database ${SCHEMA_NAME} -location ${BACKUP_PATH} -timestamp ${TIMESTAMP} -dbuser ${HANADB_USER} -dbpassword "****" ${OVERWRITE} -t ${WORKING_PATH} >>$LOG_FILEPATH 2>&1
			sudo LC_ALL=en_US.UTF-8 LD_LIBRARY_PATH=$LD_LIBRARY_PATH:${BACKUP_TOOL_LIBRARY_PATH} ${BACKUP_TOOL} ${BACKUP_ACTION} -dbserver ${HANADB_INST} -database ${SCHEMA_NAME} -location ${BACKUP_PATH} -timestamp ${TIMESTAMP} -dbuser ${HANADB_USER} -dbpassword ${HANADB_PASS} ${OVERWRITE} -t ${WORKING_PATH} >>$LOG_FILEPATH 2>&1
		fi
	else
		if [ ! -z ${NEW_SCHEMA_NAME} ]; then
			log ${BACKUP_TOOL} ${BACKUP_ACTION} -dbserver ${HANADB_INST} -database ${SCHEMA_NAME} -newdbname ${NEW_SCHEMA_NAME} -location ${BACKUP_PATH} -dbuser ${HANADB_USER} -dbpassword "****" ${OVERWRITE} -t ${WORKING_PATH} >>$LOG_FILEPATH 2>&1
			sudo LC_ALL=en_US.UTF-8 LD_LIBRARY_PATH=$LD_LIBRARY_PATH:${BACKUP_TOOL_LIBRARY_PATH} ${BACKUP_TOOL} ${BACKUP_ACTION} -dbserver ${HANADB_INST} -database ${SCHEMA_NAME} -newdbname ${NEW_SCHEMA_NAME} -location ${BACKUP_PATH} -dbuser ${HANADB_USER} -dbpassword ${HANADB_PASS} ${OVERWRITE} -t ${WORKING_PATH} >>$LOG_FILEPATH 2>&1
		else
			log ${BACKUP_TOOL} ${BACKUP_ACTION} -dbserver ${HANADB_INST} -database ${SCHEMA_NAME} -location ${BACKUP_PATH} -dbuser ${HANADB_USER} -dbpassword "****" ${OVERWRITE} -t ${WORKING_PATH} >>$LOG_FILEPATH 2>&1
			sudo LC_ALL=en_US.UTF-8 LD_LIBRARY_PATH=$LD_LIBRARY_PATH:${BACKUP_TOOL_LIBRARY_PATH} ${BACKUP_TOOL} ${BACKUP_ACTION} -dbserver ${HANADB_INST} -database ${SCHEMA_NAME} -location ${BACKUP_PATH} -dbuser ${HANADB_USER} -dbpassword ${HANADB_PASS} ${OVERWRITE} -t ${WORKING_PATH} >>$LOG_FILEPATH 2>&1
		fi
	fi
	backupExitCode=$?
	log Imported: Timestamp:${NOW} BackupExitCode:${backupExitCode}
elif [ ${BACKUP_ACTION} = "copy_export" ]; then
    if [ ! -z ${GUID} ]; then
		log "GUID:${GUID}"
	else
		log "GUID:"
	fi
	log "Copying file operation started: Timestamp:${NOW} BackupPath:${COPYBACKUPPATH} LogFile:${LOG_FILEPATH}"
	if [ -z ${COPYSUBFOLDER} ]; then
	    log ${BACKUP_TOOL} ${BACKUP_ACTION} -server ${COPYSERVER} -user ${COPYUSER} -password "****" -backuppath ${COPYBACKUPPATH} >>$LOG_FILEPATH 2>&1
	    sudo LC_ALL=en_US.UTF-8 LD_LIBRARY_PATH=$LD_LIBRARY_PATH:${BACKUP_TOOL_LIBRARY_PATH} ${BACKUP_TOOL} ${BACKUP_ACTION} -server ${COPYSERVER} -user ${COPYUSER} -password ${COPYPASSWORD} -backuppath ${COPYBACKUPPATH} >>$LOG_FILEPATH 2>&1
	else
	    log ${BACKUP_TOOL} ${BACKUP_ACTION} -server ${COPYSERVER} -subfolder ${COPYSUBFOLDER} -user ${COPYUSER} -password "****" -backuppath ${COPYBACKUPPATH} >>$LOG_FILEPATH 2>&1
	    sudo LC_ALL=en_US.UTF-8 LD_LIBRARY_PATH=$LD_LIBRARY_PATH:${BACKUP_TOOL_LIBRARY_PATH} ${BACKUP_TOOL} ${BACKUP_ACTION} -server ${COPYSERVER} -subfolder ${COPYSUBFOLDER} -user ${COPYUSER} -password ${COPYPASSWORD} -backuppath ${COPYBACKUPPATH} >>$LOG_FILEPATH 2>&1
	fi
    backupExitCode=$?
	log "Copying file operation finished: Timestamp:${NOW} BackupExitCode:${backupExitCode}"
elif [ ${BACKUP_ACTION} = "check_open_sessions" ]; then
	log ${BACKUP_TOOL} ${BACKUP_ACTION} -dbserver ${HANADB_INST} -database ${SCHEMA_NAME} -dbuser ${HANADB_USER} -dbpassword "****" >>$LOG_FILEPATH 2>&1
	sudo LC_ALL=en_US.UTF-8 LD_LIBRARY_PATH=$LD_LIBRARY_PATH:${BACKUP_TOOL_LIBRARY_PATH} ${BACKUP_TOOL} ${BACKUP_ACTION} -dbserver ${HANADB_INST} -database ${SCHEMA_NAME} -dbuser ${HANADB_USER} -dbpassword ${HANADB_PASS} >>$LOG_FILEPATH 2>&1
elif [ ${BACKUP_ACTION} = "list" ]; then
	if [ -z ${SCHEMA_NAME} ]; then
		log ${BACKUP_TOOL} ${BACKUP_ACTION} -dbserver ${HANADB_INST} -location ${BACKUP_PATH} >>$LOG_FILEPATH 2>&1
		sudo LC_ALL=en_US.UTF-8 LD_LIBRARY_PATH=$LD_LIBRARY_PATH:${BACKUP_TOOL_LIBRARY_PATH} ${BACKUP_TOOL} ${BACKUP_ACTION} -dbserver ${HANADB_INST} -location ${BACKUP_PATH} >>$LOG_FILEPATH 2>&1
	else	
		log ${BACKUP_TOOL} ${BACKUP_ACTION} -dbserver ${HANADB_INST} -database ${SCHEMA_NAME} -location ${BACKUP_PATH} >>$LOG_FILEPATH 2>&1
		sudo LC_ALL=en_US.UTF-8 LD_LIBRARY_PATH=$LD_LIBRARY_PATH:${BACKUP_TOOL_LIBRARY_PATH} ${BACKUP_TOOL} ${BACKUP_ACTION} -dbserver ${HANADB_INST} -database ${SCHEMA_NAME} -location ${BACKUP_PATH} >>$LOG_FILEPATH 2>&1
	fi
elif [[ ${BACKUP_ACTION} = "backup_server" ]]; then
	if [ ${LIMIT} > 0 ]; then
		if [[ ${DELETE_OLDER_BACKUPS} = "Yes" ]]; then
			log ${BACKUP_TOOL} ${BACKUP_ACTION} -dbserver ${HANADB_INST} -location ${BACKUP_PATH} -dbuser ${HANADB_USER} -dbpassword "****" -limit ${LIMIT} ${OVERWRITE} -t ${WORKING_PATH} >>$LOG_FILEPATH 2>&1
			sudo LC_ALL=en_US.UTF-8 LD_LIBRARY_PATH=$LD_LIBRARY_PATH:${BACKUP_TOOL_LIBRARY_PATH} ${BACKUP_TOOL} ${BACKUP_ACTION} -dbserver ${HANADB_INST} -location ${BACKUP_PATH} -dbuser ${HANADB_USER} -dbpassword ${HANADB_PASS} -limit ${LIMIT} ${OVERWRITE} -t ${WORKING_PATH} >>$LOG_FILEPATH 2>&1
			backupExitCode=$?
			if [ $backupExitCode == 0 ]; then
				log ${BACKUP_TOOL} delete_older_backups -dbserver ${HANADB_INST} -location ${BACKUP_PATH} -dbuser ${HANADB_USER} -dbpassword "****" -t ${WORKING_PATH} >>$LOG_FILEPATH 2>&1
				sudo LC_ALL=en_US.UTF-8 LD_LIBRARY_PATH=$LD_LIBRARY_PATH:${BACKUP_TOOL_LIBRARY_PATH} ${BACKUP_TOOL} delete_older_backups -dbserver ${HANADB_INST} -location ${BACKUP_PATH} -dbuser ${HANADB_USER} -dbpassword ${HANADB_PASS} -t ${WORKING_PATH} >>$LOG_FILEPATH 2>&1
			else
				log Finish: Timestamp:${NOW} BackupExitCode:${backupExitCode}
				echo "----------------------------" >>$LOG_FILEPATH
				exit
			fi
		else		
			log ${BACKUP_TOOL} ${BACKUP_ACTION} -dbserver ${HANADB_INST} -location ${BACKUP_PATH} -dbuser ${HANADB_USER} -dbpassword "****" -limit ${LIMIT} ${OVERWRITE} -t ${WORKING_PATH} >>$LOG_FILEPATH 2>&1
			sudo LC_ALL=en_US.UTF-8 LD_LIBRARY_PATH=$LD_LIBRARY_PATH:${BACKUP_TOOL_LIBRARY_PATH} ${BACKUP_TOOL} ${BACKUP_ACTION} -dbserver ${HANADB_INST} -location ${BACKUP_PATH} -dbuser ${HANADB_USER} -dbpassword ${HANADB_PASS} -limit ${LIMIT} ${OVERWRITE} -t ${WORKING_PATH} >>$LOG_FILEPATH 2>&1
		fi
	else
		if [[ ${DELETE_OLDER_BACKUPS} = "Yes" ]]; then
			log ${BACKUP_TOOL} ${BACKUP_ACTION} -dbserver ${HANADB_INST} -location ${BACKUP_PATH} -dbuser ${HANADB_USER} -dbpassword "****" -t ${WORKING_PATH} >>$LOG_FILEPATH 2>&1
			sudo LC_ALL=en_US.UTF-8 LD_LIBRARY_PATH=$LD_LIBRARY_PATH:${BACKUP_TOOL_LIBRARY_PATH} ${BACKUP_TOOL} ${BACKUP_ACTION} -dbserver ${HANADB_INST} -location ${BACKUP_PATH} -dbuser ${HANADB_USER} -dbpassword ${HANADB_PASS} -t ${WORKING_PATH} >>$LOG_FILEPATH 2>&1
			backupExitCode=$?
			if [ $backupExitCode == 0 ]; then
				log ${BACKUP_TOOL} delete_older_backups -dbserver ${HANADB_INST} -location ${BACKUP_PATH} -dbuser ${HANADB_USER} -dbpassword "****" -t ${WORKING_PATH} >>$LOG_FILEPATH 2>&1
				sudo LC_ALL=en_US.UTF-8 LD_LIBRARY_PATH=$LD_LIBRARY_PATH:${BACKUP_TOOL_LIBRARY_PATH} ${BACKUP_TOOL} delete_older_backups -dbserver ${HANADB_INST} -location ${BACKUP_PATH} -dbuser ${HANADB_USER} -dbpassword ${HANADB_PASS} -t ${WORKING_PATH} >>$LOG_FILEPATH 2>&1
			else
				log Finish: Timestamp:${NOW} BackupExitCode:${backupExitCode}
				echo "----------------------------" >>$LOG_FILEPATH
				exit
			fi
		else
			log ${BACKUP_TOOL} ${BACKUP_ACTION} -dbserver ${HANADB_INST} -location ${BACKUP_PATH} -dbuser ${HANADB_USER} -dbpassword "****" -t ${WORKING_PATH} >>$LOG_FILEPATH 2>&1
			sudo LC_ALL=en_US.UTF-8 LD_LIBRARY_PATH=$LD_LIBRARY_PATH:${BACKUP_TOOL_LIBRARY_PATH} ${BACKUP_TOOL} ${BACKUP_ACTION} -dbserver ${HANADB_INST} -location ${BACKUP_PATH} -dbuser ${HANADB_USER} -dbpassword ${HANADB_PASS} -t ${WORKING_PATH} >>$LOG_FILEPATH 2>&1
		fi
	fi
	backupExitCode=$?
	log Finish: Timestamp:${NOW} BackupExitCode:${backupExitCode}
elif [[ ${BACKUP_ACTION} = "delete_older_backups" ]]; then
	log ${BACKUP_TOOL} ${BACKUP_ACTION} -dbserver ${HANADB_INST} -location ${BACKUP_PATH} -dbuser ${HANADB_USER} -dbpassword "****" -t ${WORKING_PATH} >>$LOG_FILEPATH 2>&1
	sudo LC_ALL=en_US.UTF-8 LD_LIBRARY_PATH=$LD_LIBRARY_PATH:${BACKUP_TOOL_LIBRARY_PATH} ${BACKUP_TOOL} ${BACKUP_ACTION} -dbserver ${HANADB_INST} -location ${BACKUP_PATH} -dbuser ${HANADB_USER} -dbpassword ${HANADB_PASS} -t ${WORKING_PATH} >>$LOG_FILEPATH 2>&1
else
	if [ ${LIMIT} > 0 ]; then
		log ${BACKUP_TOOL} ${BACKUP_ACTION} ${COMPRESS} ${KILL_OPEN_SESSIONS} -dbserver ${HANADB_INST} -database ${SCHEMA_NAME} -location ${BACKUP_PATH} -dbuser ${HANADB_USER} -dbpassword "****" -limit ${LIMIT} ${OVERWRITE} -t ${WORKING_PATH} >>$LOG_FILEPATH 2>&1
		sudo LC_ALL=en_US.UTF-8 LD_LIBRARY_PATH=$LD_LIBRARY_PATH:${BACKUP_TOOL_LIBRARY_PATH} ${BACKUP_TOOL} ${BACKUP_ACTION} ${COMPRESS} ${KILL_OPEN_SESSIONS} -dbserver ${HANADB_INST} -database ${SCHEMA_NAME} -location ${BACKUP_PATH} -dbuser ${HANADB_USER} -dbpassword ${HANADB_PASS} -limit ${LIMIT} ${OVERWRITE} -t ${WORKING_PATH} >>$LOG_FILEPATH 2>&1
	else
		log ${BACKUP_TOOL} ${BACKUP_ACTION} ${COMPRESS} ${KILL_OPEN_SESSIONS} -dbserver ${HANADB_INST} -database ${SCHEMA_NAME} -location ${BACKUP_PATH} -dbuser ${HANADB_USER} -dbpassword "****" ${OVERWRITE} -t ${WORKING_PATH} >>$LOG_FILEPATH 2>&1
		sudo LC_ALL=en_US.UTF-8 LD_LIBRARY_PATH=$LD_LIBRARY_PATH:${BACKUP_TOOL_LIBRARY_PATH} ${BACKUP_TOOL} ${BACKUP_ACTION} ${COMPRESS} ${KILL_OPEN_SESSIONS} -dbserver ${HANADB_INST} -database ${SCHEMA_NAME} -location ${BACKUP_PATH} -dbuser ${HANADB_USER} -dbpassword ${HANADB_PASS} ${OVERWRITE} -t ${WORKING_PATH} >>$LOG_FILEPATH 2>&1
	fi
	backupExitCode=$?
	log Finish: Timestamp:${NOW} BackupExitCode:${backupExitCode}
fi
echo "----------------------------" >>$LOG_FILEPATH

